@@ -1,7 +1,7 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2017, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 /* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
 
@@ -12,7 +12,7 @@ const PopupMenu = imports.ui.popupMenu;
 
 const _ = Gettext.domain('GPaste').gettext;
 
-const GPasteStateSwitch = new Lang.Class({
+var GPasteStateSwitch = new Lang.Class({
     Name: 'GPasteStateSwitch',
     Extends: PopupMenu.PopupSwitchMenuItem,
 
@@ -20,20 +20,16 @@ const GPasteStateSwitch = new Lang.Class({
         this.parent(_("Track changes"), client.is_active());
 
         this._client = client;
-        this._fromDaemon = false;
 
-        this.connect('toggled', Lang.bind(this, this._onToggle));
+        this.connect('toggled', this._onToggle.bind(this));
     },
 
     toggle: function(state) {
-        this._fromDaemon = true;
-        this.setToggleState(state);
-        this._fromDaemon = false;
+        if (state !== this.state)
+            this.parent();
     },
 
-    _onToggle: function() {
-        if (!this._fromDaemon) {
-            this._client.track(this.state, null);
-        }
+    _onToggle: function(state) {
+        this._client.track(this.state, null);
     }
 });
